.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay 

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

simd_batch
==========

.. doxygenclass:: xsimd::simd_batch
   :project: xsimd
   :members:

Arithmetic operators
--------------------

.. doxygengroup:: simd_batch_arithmetic
   :project: xsimd
   :content-only:

Comparison operators
--------------------

.. doxygengroup:: simd_batch_comparison
   :project: xsimd
   :content-only:

Bitwise operators
-----------------

.. doxygengroup:: simd_batch_bitwise
   :project: xsimd
   :content-only:

Reducers
--------

.. doxygengroup:: simd_batch_reducers
   :project: xsimd
   :content-only:

Miscellaneous
-------------

.. doxygengroup:: simd_batch_miscellaneous
   :project: xsimd
   :content-only:

Other operators
---------------

.. doxygenfunction:: xsimd::operator!(const simd_batch<X>&)
   :project: xsimd

.. doxygenfunction:: xsimd::operator<<(std::ostream&, const simd_batch<X>&)
   :project: xsimd
